-- Grab local references to global variables. We are trading RAM to decrease CPU usage and hopefully increase FPS
local C_Map = C_Map
local LibStub = LibStub
local UnitClassBase = UnitClassBase
local UnitFactionGroup = UnitFactionGroup

------------------- Get addon reference --------------------
---@class RepByZone: AceAddon, AceEvent-3.0, AceConsole-3.0
local RepByZone = LibStub("AceAddon-3.0"):GetAddon("RepByZone")

local H = UnitFactionGroup("player") == "Horde"
local A = UnitFactionGroup("player") == "Alliance"
local playerClass = UnitClassBase("player")

function RepByZone:ZoneAndFactionList()
    -- [UImapID] = factionID
    -- If an UImapID is not listed, that zone has no associated factionID
    -- see https://wow.gamepedia.com/UiMapID or https://wago.tools/db2/UiMap for the list of UImapIDs
    -- see https://wow.gamepedia.com/FactionID for the list of factionIDs

    local zonesAndFactions = {
        --------- Vanilla ----------
        [1]         = 46,       -- Durotar/Orgrimmar
        [3]         = 72,       -- Tiragarde Keep/Stormwind
        [4]         = 72,       -- Tiragarde Keep (Great Hall)/Stormwind
        [7]         = 81,       -- Mulgore/Thunder Bluff
        [10]        = A and 470 or H and 76, -- Northern Barrens/Ratchet or Orgrimmar
        [14]        = A and 509 or H and 510, -- Arathi Highlands/The League of Arathor or The Defilers
        [15]        = A and 47 or H and 76, -- Badlands/Ironforge or Orgrimmar
        [17]        = A and 72 or H and 76, -- Blasted Lands/Stormwind or Orgrimmar
        [18]        = 68,       -- Tirisfal Glades/Undercity
        [21]        = A and 1134 or H and 68, -- Silverpine Forest/Gilneas or Undercity
        [22]        = 1106,     -- Western Plaguelands/Argent Crusade
        [23]        = 1106,     -- Eastern Plaguelands/Argent Crusade
        [25]        = 68,       -- Hillsbrad Foothills/Undercity
        [26]        = A and 1174 or H and 530, -- Hinterlands/Wildhammer Clan or Darkspear Trolls
        [27]        = 47,       -- Dun Morogh/Ironforge
        [30]        = 54,       -- New Tinkertown/Gnomeregan
        [32]        = 59,       -- Searing Gorge/Thorium Brotherhood
        [36]        = A and 72 or H and 76, -- Burning Steppes/Stormwind or Orgrimmar
        [37]        = 72,       -- Elwynn Forest/Stormwind
        [41]        = 1090,     -- Dalaran Crater/Kirin Tor
        [42]        = 967,      -- Deadwind Pass/The Violet Eye
        [47]        = A and 72 or H and 68, -- Duskwood/Stormwind or Undercity
        [48]        = 47,       -- Loch Modan/Ironforge
        [49]        = 72,       -- Redridge Mountains/Stormwind
        [50]        = A and 72 or H and 76, -- Northern Stranglethorn/Stormwind or Orgrimmar
        [51]        = 76,       -- Swamp of Sorrows/Orgimmar
        [52]        = 72,       -- Westfall/Stormwind
        [56]        = 47,       -- Wetlands/Ironforge
        [57]        = 69,       -- Teldrassil/Darnassus
        [62]        = 69,       -- Darkshore/Darnassus
        [63]        = A and 69 or H and 1085, -- Ashenvale/Darnassus or Warsong Offensive
        [64]        = A and 54 or H and 1133, -- Thousand Needles/Gnomeregan or Bilgewater Cartel
        [65]        = A and 69 or H and 81, -- Stonetalon Mountains/Darnassus or Thunder Bluff
        [66]        = 609,      -- Desolace/Cenarion Circle
        [69]        = A and 69 or H and 81, -- Feralas/Darnassus or Thunder Bluff
        [70]        = A and 72 or H and 76, -- Dustwallow Marsh/Stormwind or Orgrimmar
        [71]        = 369,      -- Tanaris/Gadgetzan
        [74]        = 989,      -- Timeless Tunnel/Keepers of Time
        [75]        = 989,      -- Caverns of Time/Keepers of Time
        [76]        = 1133,     -- Azshara/Bilgewater Cartel
        [77]        = A and 69 or H and 1133, -- Felwood/Darnassus or Bilgewater Cartel
        [80]        = 609,      -- Moonglade/Cenarion Circle
        [81]        = 609,      -- Silithus/Cenarion Circle
        [83]        = 577,      -- Winterspring/Everlook
        [84]        = 72,       -- Stormwind City/Stormwind
        [85]        = 76,       -- Orgrimmar/Orgrimmar
        [87]        = 47,       -- Ironforge/Ironforge
        [88]        = 81,       -- Thunder Bluff/Thunder Bluff
        [89]        = 69,       -- Darnassus/Darnassus
        [90]        = 68,       -- Undercity/Undercity

        --------- TBC ---------
        [94]        = 911,      -- Eversong Woods/Silvermoon City
        [95]        = 922,      -- Ghostlands/Tranquillien
        [97]        = 930,      -- Azuremyst Isle/Exodar
        [100]       = A and 946 or H and 947, -- Hellfire Peninsula/Honor Hold or Thrallmar
        [102]       = 942,      -- Zangarmarsh/Cenarion Expedition
        [103]       = 930,      -- The Exodar/Exodar
        [104]       = 1012,     -- Shadowmoon Valley/Ashtongue Deathsworn
        [106]       = 930,      -- Bloodmyst Isle/Exodar
        [107]       = A and 978 or H and 941, -- Nagrand/Kurenai or The Mag'har
        [108]       = 1011,     -- Terokkar Forest/Lower City
        [109]       = 933,      -- Netherstorm/The Consortium
        [110]       = 911,      -- Silvermoon City/Silvermoon City
        [111]       = 935,      -- Shattrath City/The Sha'tar
        [122]       = 1077,     -- Isle of Quel'Danas/Shattered Sun Offensive

        --------- WotLK ---------
        [114]       = A and 1050 or H and 1085, -- Borean Tundra/Valiance Expedition or Warsong Offensive
        [115]       = 1091,     -- Dragonblight/The Wyrmrest Accord
        [116]       = A and 1050 or H and 1085, -- Grizzly Hills/Valiance Expedition or Warsong Offensive
        [117]       = A and 1050 or H and 1067, -- Howling Fjord/Valiance Expedition or The Hand of Vengeance
        [118]       = 1098,     -- Icecrown/Knights of the Ebon Blade
        [119]       = self.sholazarRepID, -- See Core-Retail.lua's CheckSholazarBasin()
        [120]       = 1119,     -- The Storm Peaks/The Sons of Hodir
        [121]       = 1106,     -- Zul'Drak/Argent Crusade
        [123]       = A and 1050 or H and 1052, -- Wintergrasp/Valiance Expedition or Horde Expedition
        [124]       = 1098,     -- Plaguelands: The Scarlet Enclave (DK starting zone)/Knights of the Ebon Blade
        [125]       = 1090,     -- Dalaran City/Kirin Tor
        [126]       = 1090,     -- Dalaran City (The Underbelly)/Kirin Tor
        [127]       = 1090,     -- Crystalsong Forest/Kirin Tor
        [170]       = 1106,     -- Hrothgar's Landing/Argent Crusade
        [1360]      = 1098,     -- Icecrown Citadel (The Frozen Throne)/Knights of the Ebon Blade

        --------- Cataclysm ---------
        [174]       = 1133,     -- The Lost Isles/Bilgewater Cartel
        [179]       = 1134,     -- Gilneas/Gilneas
        [194]       = 1133,     -- Kezan/Bilgewater Cartel
        [198]       = 1158,     -- Mount Hyjal/Guardians of Hyjal
        [199]       = A and 72 or H and 76, -- Southern Barrens/Stormwind or Orgrimmar
        [201]       = 1135,     -- Kelp'thar Forest/The Earthen Ring
        [202]       = 1134,     -- Gilneas City/Gilneas
        [203]       = 1135,     -- Vashj'ir/The Earthen Ring
        [204]       = 1135,     -- Abyssal Depths/The Earthen Ring
        [205]       = 1135,     -- Shimmering Expanse/The Earthen Ring
        [207]       = 1135,     -- Deephom/The Earthen Ring
        [210]       = A and 72 or H and 76, -- The Cape of Stranglethorn/Stormwind or Orgrimmar
        [217]       = A and 1134 or H and 68, -- Ruins of Gilneas/Gilneas or Undercity
        [218]       = 1134,     -- Ruins of Gilneas City/Gilneas
        [224]       = A and 72 or H and 76, -- Stranglethorn Vale/Stormwind or Orgrimmar
        [241]       = A and 1174 or H and 1172, -- Twilight Highlands/Wildhammer Clan or Dragonmaw Clan
        [244]       = A and 1177 or H and 1178, -- Tol Barad/Baradin's Warders or Hellscream's Reach
        [245]       = A and 1177 or H and 1178, -- Tol Barad Peninsula/Baradin's Warders or Hellscream's Reach
        [249]       = 1173,     -- Uldum/Ramkahen
        [276]       = 1135,     -- The Maelstrom/The Earthen Ring
        [738]       = 1204,     -- Firelands/Avengers of Hyjal

        --------- MoP ---------
        [371]       = A and 1242 or H and 1228, -- Jade Forest/Pearlfin Jinyu or Forest Hozen
        [376]       = 1272,     -- Valley of the Four Winds/The Tillers
        [378]       = A and 1353 or H and 1352 or 1216, -- The Wandering Isle/Tushui Pandaren or Huojin Pandaren or Shang Xi's Academy
        [379]       = 1270,     -- Kun-Lai Summit/Shado-Pan
        [388]       = 1270,     -- Towlong Steppes/Shado-Pan
        [390]       = 1269,     -- Vale of Eternal Blossoms/Golden Lotus
        [407]       = 909,      -- Darkmoon Island (orphan)/Darkmoon Faire
        [408]       = 909,      -- Darkmoon Island (dungeon)/Darkoon Faire
        [418]       = 1302,     -- Krasarang Wilds/The Anglers
        [422]       = 1337,     -- Dread Wastes/The Klaxxi
        [425]       = 72,       -- Northshire/Stormwind
        [433]       = 1359,     -- The Veiled Stair/The Black Prince
        [507]       = A and 72 or H and 76, -- Isle of Giants/Stormwind or Orgrimmar
        [516]       = A and 1387 or H and 1388, -- Isle of Thunder/Kirin Tor Offensive or Sunreaver Onslaught
        [554]       = 1492,     -- Timeless Isle/Emperor Shaohao

        --------- WoD ---------
        [525]       = 1445,     -- Frostfire Ridge/Frostwolf Orcs
        [534]       = A and 1847 or H and 1848, -- Tanaan Jungle/Hand of the Prophet or Vol'jin's Headhunters
        [535]       = A and 1731 or H and 1445, -- Talador/Council of Exarchs or Frostwolf Orcs
        [539]       = 1731,     -- Shadowmoon Valley/Council of Exarchs
        [542]       = 1515,     -- Spires of Arak/Arakkoa Outcasts
        [543]       = A and 930 or H and 1708, -- Gorgrond/Exodar or Laughing Skull Orcs
        [550]       = 1711,     -- Nagrand/Steamwheedle Preservation Society
        [579]       = 72,       -- Lunarfall Excavation 1/Stormwind
        [580]       = 72,       -- Lunarfall Excavation 2/Stormwind
        [581]       = 72,       -- Lunarfall Excavation 3/Stormwind
        [582]       = 72,       -- Lunarfall/Stormwind
        [585]       = 76,       -- Frostwall Mine 1/Orgimmar
        [586]       = 76,       -- Frostwall Mine 2/Orgimmar
        [587]       = 76,       -- Frostwall Mine 3/Orgrimmar
        [588]       = A and 1682 or H and 1681, -- Ashran/Wrynn's Vanguard or Vol'jin's Spear
        [590]       = 76,       -- Frostwall/Orgrimmar
        [622]       = A and 1682 or H and 1681, -- Stormshield/Wrynn's Vanguard or Vol'jin's Spear

        --------- Legion ---------
        [626]       = 349,      -- Dalaran: Hall of Shadows (Rogue Class Hall)/Ravenholdt
        [627]       = 1090,     -- Dalaran City/Kirin Tor
        [628]       = 1090,     -- Dalaran: The Underbelly/Kirin Tor
        [629]       = 1090,     -- Dalran: Aegwynn's Gallery/Kirin Tor
        [630]       = 1900,     -- Azsuna/Court of Farondis
        [634]       = 1948,     -- Stormheim/Valarjar
        [641]       = 1883,     -- Val'sharah/Dreamweavers
        [646]       = 2045,     -- Broken Shore/Armies of Legionfall
        [647]       = 1098,     -- Acherus (Death Knight Class Hall)/Knights of the Ebon Blade
        [648]       = 1098,     -- Acherus (Death Knight Class Hall)/Knights of the Ebon Blade
        [650]       = 1828,     -- Highmountain/Highmountain Tribe
        [680]       = 1859,     -- Suramar/The Nightfallen
        [695]       = 1948,     -- Skyhold (Warrior Class Hall)/Valarjar
        [702]       = A and 930 or H and 68, -- Netherlight Temple (Priest Class Hall)/Exodar or Undercity
        [709]       = 1341,     -- The Wandering Isle (Monk Class Hall)/The August Celestials
        [715]       = 609,      -- Emerald Dreamway/Cenarion Circle
        [717]       = A and 72 or H and 76, -- Dreadscar Rift (Warlock Class Hall)/Stormwind or Orgrimmar
        [718]       = A and 72 or H and 76, -- Dreadscar Rift (Warlock Class Hall)/Stormwind or Orgrimmar
        [726]       = 1135,     -- The Maelstrom/The Earthen Ring
        [734]       = 1090,     -- Hall of the Guardian (Mage Class Hall)/Kirin Tor
        [735]       = 1090,     -- The Guardian's Library (Mage Class Hall)/Kirin Tor
        [739]       = A and 69 or H and 1828, -- Trueshot Lodge (Hunter Class Hall)/Darnassus or Highmountain Tauren
        [747]       = 609,      -- The Dreamgrove/Cenarion Circle
        [750]       = 1828,     -- Thunder Totem/Highmountain Tribe
        [787]       = 609,      -- Moonglade/Cenarion Circle
        [790]       = 1894,     -- Eye of Azshara/The Wardens
        [830]       = 2170,     -- Krokuun/Argussian Reach
        [882]       = 2170,     -- Eredath (formerly Mac'Aree)/Argussian Reach
        [1474]      = 1135,     -- Heart of Azeroth (Shaman Class Hall)/The Earthen Ring

        --------- BfA ---------
        [862]       = A and 2159 or H and 2378, -- Zuldazar/7th Legion or Zandalari Empire
        [863]       = A and 2159 or H and 2380, -- Nazmir/7th Legion or Talanji's Expedition
        [864]       = A and 2159 or H and 2382, -- Vol'dun/7th Legion or Voldunai
        [895]       = A and 2160 or H and 2157, -- Tiragarde Sound/Proudmore Admiralty or The Honorbound
        [896]       = A and 2383 or H and 2157, -- Drustvar/Order of Embers or The Honorbound
        [942]       = A and 2381 or H and 2157, -- Stormsong Valley/Storm's Wake or The Honorbound
        [1161]      = A and 2160 or H and 2157, -- Borealus/Proudmore Admiralty or The Honorbound
        [1163]      = A and 2159 or H and 2378, -- Dazar'alor: The Great Seal/7th Legion or Zandalari Empire
        [1164]      = A and 2159 or H and 2378, -- Dazar'alor: Hall of Chroniclers/7th Legion or Zandalari Empire
        [1165]      = A and 2159 or H and 2378, -- Dazar'alor/7th Legion or Zandalari Empire
        [1193]      = A and 2159 or H and 2378, -- Zuldazar/7th Legion or Zandalari Empire
        [1355]      = A and 2400 or H and 2373, -- Nazjatar/Waveblade Ankoan or The Unshackled
        [1462]      = 2391,     -- Mechagon Island/Rustbolt Resistance
        [1527]      = 2417,     -- Uldum/Uldum Accord
        [1530]      = 2415,     -- Vale of Eternal Blossoms/Rajani
        [1570]      = 2415,     -- Vale of Eternal Blossoms/Rajani
        [1571]      = 2417,     -- Uldum/Uldum Accord

        --------- Shadowlands ---------
        [1525]      = 2413,     -- Revendreth/Court of Harvesters
        [1533]      = 2407,     -- Bastion/The Ascended
        [1536]      = 2410,     -- Maldraxxus/The Undying Army
        [1543]      = 2432,     -- The Maw/Ve'nari
        [1565]      = 2465,     -- Ardenweald/The Wild Hunt
        [1569]      = 2407,     -- Bastion/The Ascended
        [1603]      = 2465,     -- Ardenweald/The Wild Hunt
        [1648]      = 2432,     -- The Maw/Ve'nari
        [1670]      = self.covenantRepID, -- Oribos: Ring of Fates/Covenant
        [1671]      = self.covenantRepID, -- Oribos: Ring of Transference/Covenant
        [1672]      = self.covenantRepID, -- Oribos: The Broker's Den/Covenant
        [1673]      = self.covenantRepID, -- Oribos: The Crucible/Covenant
        [1688]      = 2413,     -- Revendreth/Court of Havesters
        [1689]      = 2410,     -- Maldraxxus/The Undying Army
        [1701]      = 2465,     -- Heart of the Forest/The Wild Hunt
        [1702]      = 2465,     -- Heart of the Forest/The Wild Hunt
        [1703]      = 2465,     -- Heart of the Forest/The Wild Hunt
        [1707]      = 2407,     -- Elysian Hold/The Ascended
        [1708]      = 2407,     -- Sanctum of Binding/The Ascended
        [1709]      = 2465,     -- Ardenweald/The Wild Hunt
        [1734]      = 2413,     -- Revendreth/Court of Harvesters
        [1738]      = 2413,     -- Revendreth/Court of Harvesters
        [1739]      = 2465,     -- Ardenweald/The Wild Hunt
        [1740]      = 2465,     -- Ardenweald/The Wild Hunt
        [1741]      = 2410,     -- Maldraxxus/The Undying Army
        [1742]      = 2413,     -- Revendreth/Court of Harvesters
        [1813]      = 2407,     -- Bastion/The Ascended
        [1814]      = 2410,     -- Maldraxxus/The Undying Army
        [1911]      = 2432,     -- Torghast: Tower of the Damned/Ve'nari
        [1960]      = 2432,     -- The Maw/Ve'nari
        [1961]      = 2470,     -- Korthia/Death's Advance
        [1970]      = 2478,     -- Zereth Mortis/The Enlightened
        [1971]      = 1948,     -- Skyhold/Valarjar
        [2005]      = 2465,     -- Ardenweald/The Wild Hunt

        --------- Dragonflight ---------
        [1475]      = 2574,     -- The Emerald Dream/Dream Wardens
        [2022]      = 2510,     -- The Waking Shores/Valdrakken Accord
        [2023]      = 2503,     -- Ohn'ahran Plains/Maruuk Centaur
        [2024]      = 2511,     -- The Azure Span/Iskaara Tuskarr
        [2025]      = 2510,     -- Thaldraszus/Valdrakken Accord
        [2107]      = A and 2524 or H and 2523, -- The Forbidden Reach/Obsidian Warders or Dark Talons
        [2112]      = 2510,     -- Valdrakken/Valdrakken Accord
        [2118]      = A and 2524 or H and 2523, -- The Forbidden Reach/Obsidian Warders or Dark Talons
        [2131]      = A and 2524 or H and 2523, -- The Forbidden Reach/Obsidian Warders or Dark Talons
        [2133]      = 2564,     -- Zaralek Cavern/Loamm Niffen
        [2134]      = 2510,     -- Valdrakken/Valdrakken Accord
        [2151]      = A and 2524 or H and 2523, -- The Forbidden Reach/Obsidian Warders or Dark Talons
        [2175]      = 2564,     -- Zaralek Cavern/Loamm Niffen
        [2200]      = 2574,     -- Emerald Dream/Dream Wardens
        [2268]      = 2574,     -- Amirdrassil/Dream Wardens
    }
    return zonesAndFactions
end

function RepByZone:SubZonesAndFactionsList()
    local subZonesAndFactions = {
		-- [C_Map.GetAreaInfo(areaID)]  = factionID
        -- see https://wow.tools/dbc/?dbc=areatable&build=10.0.5.47660#page=1 or https://wago.tools/db2/AreaTable?page=1

        [C_Map.GetAreaInfo(35)]         = 21,       -- Booty Bay/Booty Bay
        [C_Map.GetAreaInfo(36)]         = A and 730 or H and 729, -- Alterac Mountains/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(43)]         = 87,       -- Wild Shore/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(100)]        = 47,       -- Nesingwary's Expedition/Ironforge
        [C_Map.GetAreaInfo(133)]        = 54,       -- New Tinkertown/Gnomeregan
		[C_Map.GetAreaInfo(150)]        = 72,       -- Menethil Harbor/Stormwind
        [C_Map.GetAreaInfo(152)]        = 1106,     -- The Bulwark/Argent Crusade
        [C_Map.GetAreaInfo(193)]        = A and 72 or H and 68, -- Ruins of Andorhal/Stormwind or Undercity
        [C_Map.GetAreaInfo(196)]        = 72,       -- Uthor's Tomb/Stormwind
        [C_Map.GetAreaInfo(197)]        = 72,       -- Sorrow Hill/Stormwind
        [C_Map.GetAreaInfo(199)]        = 72,       -- Felstone Field/Stormwind
        [C_Map.GetAreaInfo(201)]        = 68,       -- Gahrron's Withering/Undercity
        [C_Map.GetAreaInfo(202)]        = 68,       -- Writhing Haunt/Undercity
        [C_Map.GetAreaInfo(204)]        = 1134,     -- Pyrewood Village/Gilneas
        [C_Map.GetAreaInfo(233)]        = 1134,     -- Ambermill/Gilneas
        [C_Map.GetAreaInfo(250)]        = 59,       -- Ruins of Thaurissan
        [C_Map.GetAreaInfo(279)]        = 1090,     -- Dalaran Crater/Kirin Tor
        [C_Map.GetAreaInfo(280)]        = 349,      -- Strahnbrad/Ravenholdt
        [C_Map.GetAreaInfo(288)]        = 72,       -- Azurelode Mine/Stormwind
		[C_Map.GetAreaInfo(297)]        = 81,       -- Jaguero Isle/Thunder Bluff
		[C_Map.GetAreaInfo(299)]        = 72,       -- Menethil Bay/Stormwind
        [C_Map.GetAreaInfo(313)]        = 349,      -- Northfold Manor/Ravenholdt
        [C_Map.GetAreaInfo(315)]        = 72,       -- Dabyrie's Farmstead/Stormwind
        [C_Map.GetAreaInfo(317)]        = A and 1174 or H and 530, -- Witherbark Village/Wildhammer Clan or Darkspear Trolls
        [C_Map.GetAreaInfo(320)]        = 72,       -- Refuge Pointe/Stormwind
        [C_Map.GetAreaInfo(321)]        = 68,       -- Hammerfall/Undercity
        [C_Map.GetAreaInfo(324)]        = 349,      -- Stromgarde Keep/Ravenholdt
        [C_Map.GetAreaInfo(327)]        = 21,       -- Faldir's Cove/Booty Bay
        [C_Map.GetAreaInfo(328)]        = 21,       -- The Drowned Reef/Booty Bay
        [C_Map.GetAreaInfo(330)]        = 47,       -- Thandol Span/Ironforge
        [C_Map.GetAreaInfo(350)]        = 69,       -- Quel'Danil Lodge/Darnassus
		[C_Map.GetAreaInfo(359)]        = A and 47 or H and 81, -- Bael Modan/Ironforge or Thunder Bluff
        [C_Map.GetAreaInfo(367)]        = 530,      -- Sen'jen Village/Darkspear Trolls
        [C_Map.GetAreaInfo(368)]        = 530,      -- Echo Isles/Darkspear Trolls
        [C_Map.GetAreaInfo(392)]        = 470,      -- Ratchet/Ratchet
        [C_Map.GetAreaInfo(393)]        = 530,      -- Darkspear Strand/Darkspear Trolls
        [C_Map.GetAreaInfo(401)]        = H and playerClass == "SHAMAN" and 1135, -- The Tidus Stair/The Earthen Ring (only for Horde shamans)
        [C_Map.GetAreaInfo(439)]        = A and 54 or H and 76, -- The Shimmering Flats/Gnomeregan or Orgrimmar
        [C_Map.GetAreaInfo(484)]        = A and 69 or H and 81, -- Freewind Post/Darnassus or Thunder Bluff
        [C_Map.GetAreaInfo(501)]        = 369,      -- Beezil's Wreck/Gadgetzan
        [C_Map.GetAreaInfo(517)]        = 1358,     -- Tidefury Cove/Nat Pagle
		[C_Map.GetAreaInfo(596)]        = 470,      -- Kodo Graveyard/Ratchet
        [C_Map.GetAreaInfo(603)]        = 69,       -- Sargeron/Darnassus
        [C_Map.GetAreaInfo(604)]        = 93,       -- Magram Village (Shok'Thokar)/Magram Clan Centaur
        [C_Map.GetAreaInfo(606)]        = 92,       -- Gelkis Village/Gelkis Clan Centaur
        [C_Map.GetAreaInfo(608)]        = 69,       -- Nijel's Point/Darnassus
        [C_Map.GetAreaInfo(609)]        = 93,       -- Kolkar Village/Magram Clan Centaur
        [C_Map.GetAreaInfo(657)]        = 930,      -- The Harborage/Exodar
        [C_Map.GetAreaInfo(702)]        = 69,       -- Rut'theran Village/Darnassus
        [C_Map.GetAreaInfo(721)]        = 54,       -- Gnomeregan/Gnomeregan
        [C_Map.GetAreaInfo(813)]        = 1106,     -- The Bulwark/Argent Crusade
        [C_Map.GetAreaInfo(880)]        = 1174,     -- Thandol Span (Arathi Highlands)/Wildhammer Clan
        [C_Map.GetAreaInfo(881)]        = 47,       -- Thandol Span (Wetlands)/Ironforge
        [C_Map.GetAreaInfo(896)]        = A and 730 or H and 729, -- Purgation Isle/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(978)]        = A and 1174 or H and 530, -- Zul'Farrak/Wildhammer Clan or Darkspear Trolls
        [C_Map.GetAreaInfo(987)]        = 1133,     -- Land's End Beach/Bilgewater Cartel
        [C_Map.GetAreaInfo(989)]        = 1173,     -- Ruins of Uldum/Ramkahen
        [C_Map.GetAreaInfo(990)]        = 1173,     -- Valley of the Watchers/Ramkahen
        [C_Map.GetAreaInfo(1016)]       = 69,       -- Direforge Hill/Darnassus
        [C_Map.GetAreaInfo(1025)]       = 69,       -- The Green Belt/Darnassus
        [C_Map.GetAreaInfo(1057)]       = A and 47 or H and 68, -- Thoradin's Wall (Hillsbrad Foothills)/Ironforge or Undercity
        [C_Map.GetAreaInfo(1216)]       = 579,      -- Timbermaw Hold/Timbermaw Hold
        [C_Map.GetAreaInfo(1220)]       = 69,       -- Darnassian Base Camp/Darnassus
        [C_Map.GetAreaInfo(1336)]       = A and 54 or H and 1133, -- Lost Rigger Cove/Gnomeregan or Bilgewater Cartel
        [C_Map.GetAreaInfo(1446)]       = 59,       -- Thorium Point/Thorium Brotherhood
		[C_Map.GetAreaInfo(1658)]       = 609,      -- Cenarion Enclave/Cenarion Circle
        [C_Map.GetAreaInfo(1677)]       = A and 730 or H and 729, -- Gavin's Naze/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(1678)]       = 72,       -- Sofera's Naze/Stormwind
        [C_Map.GetAreaInfo(1679)]       = A and 730 or H and 729, -- Corrahn's Dagger/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(1680)]       = A and 730 or H and 729, -- The Headland/Stormpike Guard or Frostwolf Clan
		[C_Map.GetAreaInfo(1739)]       = 1133,     -- Hardwrench Hideaway/Bilgewater Cartel
        [C_Map.GetAreaInfo(1741)]       = 87,       -- Gurubashi Arena/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(1757)]       = 87,       -- The Crimson Veil/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(1758)]       = 87,       -- The Riptide/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(1759)]       = 87,       -- The Damsel's Luck/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(1761)]       = 579,      -- Deadwood Village/Timbermaw Hold
        [C_Map.GetAreaInfo(1762)]       = 579,      -- Felpaw Village/Timbermaw Hold
        [C_Map.GetAreaInfo(1769)]       = 579,      -- Timbermaw Hold/Timbermaw Hold
        [C_Map.GetAreaInfo(1778)]       = 369,      -- Sorrowmurk/Gadgetzan
        [C_Map.GetAreaInfo(1797)]       = 1133,     -- Stagalbog/Bilgewater Cartel
        [C_Map.GetAreaInfo(1837)]       = A and 1174 or H and 530, -- Witherbark Caverns/Wildhammer Clan or Darkspear Trolls
        [C_Map.GetAreaInfo(1857)]       = A and 47 or H and 68, -- Thoradin's Wall (Arathi Highlands)/Ironforge or Undercity
		[C_Map.GetAreaInfo(1858)]       = 1174,     -- Boulder'gor/Wildhammer Clan
        [C_Map.GetAreaInfo(1941)]       = 989,      -- Caverns of Time/Keepers of Time
        [C_Map.GetAreaInfo(1998)]       = 1134,     -- Talonbranch Glade/Gilneas
        [C_Map.GetAreaInfo(2079)]       = A and 54 or H and 68, -- Alcaz Island/Gnomeregan or Undercity
		[C_Map.GetAreaInfo(2097)]       = A and 69 or H and 81, -- Darkcloud Pinnacle/Darnassus or Thunder Bluff
		[C_Map.GetAreaInfo(2157)]       = A and 47 or H and 81, -- Bael'dun Keep/Ironforge or Thunder Bluff
        [C_Map.GetAreaInfo(2177)]       = 87,       -- Battle Ring/Bloodsail Buccaneers
		[C_Map.GetAreaInfo(2240)]       = A and 54 or H and 1133, -- Mirage Raceway/Gnomeregan or Bilgewater Cartel
        [C_Map.GetAreaInfo(2241)]       = 589,      -- Frostsaber Rock/Wintersaber Trainers
        [C_Map.GetAreaInfo(2242)]       = 69,       -- The Hidden Grove/Darnassus
        [C_Map.GetAreaInfo(2243)]       = 579,      -- Timbermaw Post/Timbermaw Hold
        [C_Map.GetAreaInfo(2244)]       = 579,      -- Winterfall Village/Timbermaw Hold
        [C_Map.GetAreaInfo(2246)]       = 579,      -- Frostfire Hot Springs/Timbermaw Hold
        [C_Map.GetAreaInfo(2248)]       = 47,       -- Dun Mandarr/Ironforge
        [C_Map.GetAreaInfo(2253)]       = 69,       -- Starfall Village/Darnassus
        [C_Map.GetAreaInfo(2257)]       = 72,       -- Deeprun Tram/Stormwind
        [C_Map.GetAreaInfo(2276)]       = 69,       -- Quel'Lithien Lodge/Darnassus
        [C_Map.GetAreaInfo(2300)]       = 989,      -- Caverns of Time/Keepers of Time
        [C_Map.GetAreaInfo(2379)]       = 72,       -- Azurelode Mine/Stormwind
        [C_Map.GetAreaInfo(2404)]       = 69,       -- Tethris Aran/Darnassus
        [C_Map.GetAreaInfo(2406)]       = 69,       -- Ranazjar Isle/Darnassus
        [C_Map.GetAreaInfo(2407)]       = 470,      -- Kormek's Hut/Ratchet
        [C_Map.GetAreaInfo(2408)]       = 530,      -- Shadowprey Village/Darkspear Trolls
        [C_Map.GetAreaInfo(2539)]       = 530,      -- Malaka'jin/Darkspear Trolls
        [C_Map.GetAreaInfo(2597)]       = A and 730 or H and 729, -- Alterac Valley/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(2617)]       = 470,      -- Scrabblescrew's Camp/Ratchet
        [C_Map.GetAreaInfo(2738)]       = 69,       -- Southwind Village/Darnassus
        [C_Map.GetAreaInfo(2839)]       = A and 730 or H and 729, -- Alterac Valley/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(2897)]       = 530,      -- Zoram'gar Outpost/Darkspear Trolls
        [C_Map.GetAreaInfo(3137)]       = 69,       -- Talrendis Point/Darnassus
		[C_Map.GetAreaInfo(3197)]       = 72,       -- Chillwind Camp/Stormwind
        [C_Map.GetAreaInfo(3319)]       = 890,      -- Silverwing Grove/Silverwing Sentinels
        [C_Map.GetAreaInfo(3426)]       = 69,       -- Staghelm Point/Darnassus
        [C_Map.GetAreaInfo(3427)]       = 47,       -- Bronzebeard Encampment/Ironforge
        [C_Map.GetAreaInfo(3486)]       = 349,      -- Ravenholdt Manor/Ravenholdt
        [C_Map.GetAreaInfo(4010)]       = 369,      -- Mudsprocket/Gadgetzan
        [C_Map.GetAreaInfo(4690)]       = 1135,     -- Thunder Peak/The Earthen Ring
        [C_Map.GetAreaInfo(4715)]       = 1133,     -- The Skunkworks/Bilgewater Cartel
        [C_Map.GetAreaInfo(4745)]       = 76,       -- Orgrimmar Rear Gate/Orgrimmar
        [C_Map.GetAreaInfo(4798)]       = 1068,     -- Thoargad's Camp/Explorer's League
        [C_Map.GetAreaInfo(4803)]       = 911,      -- Furien's Post/Silvermoon City
        [C_Map.GetAreaInfo(4882)]       = 369,      -- Marshal's Stand/Gadgetzan
        [C_Map.GetAreaInfo(4883)]       = 369,      -- Mossy Pile/Gadgetzan
        [C_Map.GetAreaInfo(4925)]       = 609,      -- Thunk's Abode/Cenarion Circle
        [C_Map.GetAreaInfo(4927)]       = 76,       -- The Fold/Orgimmar
        [C_Map.GetAreaInfo(4933)]       = 76,       -- Krom'gar Fortress/Orgimmar
        [C_Map.GetAreaInfo(4934)]       = 1133,     -- The Sludgewerks/Bilgewater Cartel
        [C_Map.GetAreaInfo(4940)]       = 1068,     -- Northwatch Expedition Base Camp/Explorer's League
        [C_Map.GetAreaInfo(5011)]       = 81,       -- Westreach Summit/Thunder Bluff
        [C_Map.GetAreaInfo(5028)]       = 87,       -- Southsea Holdfast/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(5041)]       = A and 54 or H and 1133, -- Fizzle & Pozzik's Speedbarge/Gnomeregan or Bilgewater Cartel
        [C_Map.GetAreaInfo(5044)]       = 609,      -- The Tainted Forest/Cenarion Circle
        [C_Map.GetAreaInfo(5048)]       = A and 54 or H and 1133, -- Raceway Ruins/Gnomeregan or Bilgewater Cartel
        [C_Map.GetAreaInfo(5083)]       = 911,      -- Sunveil Excursion/Silvermoon City
        [C_Map.GetAreaInfo(5117)]       = 1133,     -- Nozzlepot's Outpost/Bilgewater Cartel
        [C_Map.GetAreaInfo(5121)]       = 68,       -- Galen's Fall/Undercity
        [C_Map.GetAreaInfo(5150)]       = 47,       -- Dwarven District/Ironforge
        [C_Map.GetAreaInfo(5169)]       = 530,      -- Valley of Spirits/Darkspear Trolls
        [C_Map.GetAreaInfo(5171)]       = 81,       -- Valley of Wisdom/Thunder Bluff
        [C_Map.GetAreaInfo(5305)]       = 69,       -- Greenwarden's Grove/Darnassus
        [C_Map.GetAreaInfo(5317)]       = 530,      -- Bambala/Darkspear Trolls
        [C_Map.GetAreaInfo(5367)]       = 942,      -- The Mender's Stead/Cenarion Circle
        [C_Map.GetAreaInfo(5388)]       = 911,      -- Dawnrise Expedition/Silvermoon City
        [C_Map.GetAreaInfo(5458)]       = 369,      -- Bogpaddle/Gadgetzan
        [C_Map.GetAreaInfo(5476)]       = 1134,     -- Pyrewood Chapel/Gilneas
        [C_Map.GetAreaInfo(5477)]       = 1134,     -- Pyrewood Inn/Gilneas
        [C_Map.GetAreaInfo(5478)]       = 1134,     -- Pyrewood Town Hall/Gilneas
        [C_Map.GetAreaInfo(5480)]       = 1134,     -- Gilneas Liberation Base Camp/Gilneas
        [C_Map.GetAreaInfo(5481)]       = 2159,     -- 7th Legion Base Camp/7th Legion
        [C_Map.GetAreaInfo(5495)]       = 54,       -- Gnomeregan/Gnomeregan
        [C_Map.GetAreaInfo(5496)]       = 369,      -- Fuselight/Gadgetzan
        [C_Map.GetAreaInfo(5497)]       = 369,      -- Fuselight-by-the-Sea/Gadgetzan
        [C_Map.GetAreaInfo(5524)]       = 911,      -- Bloodwatcher Point/Silvermoon City
        [C_Map.GetAreaInfo(5564)]       = 72,       -- Dragon's Mouth/Stormwind
        [C_Map.GetAreaInfo(5645)]       = 609,      -- Whisperwind Grove/Cenarion Circle
        [C_Map.GetAreaInfo(5649)]       = 609,      -- Wildheart Point/Cenarion Circle
        [C_Map.GetAreaInfo(5654)]       = 59,       -- Chiselgrip/Thorium Brotherhood
        [C_Map.GetAreaInfo(5675)]       = A and 69 or H and 81, -- Arikara's Needle/Darnassus or Thunder Bluff
        [C_Map.GetAreaInfo(5687)]       = 1134,     -- Darnassus: The Howling Oak/Gilneas
        [C_Map.GetAreaInfo(5705)]       = A and 47 or H and 530, -- Snowden Chalet/Ironforge or Darkspear Trolls
        [C_Map.GetAreaInfo(5706)]       = 369,      -- The Steam Pools/Gadgetzan
        [C_Map.GetAreaInfo(8615)]       = 21,       -- The Salty Sailor Tavern/Booty Bay

        --------- TBC ---------
        [C_Map.GetAreaInfo(3482)]       = 922,      -- The Dead Scar (Eversong Woods)/Tranquillien
        [C_Map.GetAreaInfo(3514)]       = 922,      -- The Dead Scar (Ghostlands)/Tranquillien
        [C_Map.GetAreaInfo(3530)]       = A and 930 or H and 911, -- Shadow Ridge/Exodar or Silvermoon City
        [C_Map.GetAreaInfo(3547)]       = 1077,     -- Throne of Kil'jaeden/Shattered Sun Offensive
        [C_Map.GetAreaInfo(3552)]       = 978,      -- Temple of Telhamat/Kurenai
        [C_Map.GetAreaInfo(3554)]       = 911,      -- Falcon Watch/Silvermoon City
        [C_Map.GetAreaInfo(3555)]       = 941,      -- Mag'har Post/The Mag'har
        [C_Map.GetAreaInfo(3569)]       = 69,       -- Tides' Hollow/Darnassus
        [C_Map.GetAreaInfo(3573)]       = 72,       -- Odesyus' Landing/Stormwind
        [C_Map.GetAreaInfo(3590)]       = 69,       -- Wrathscale Lair/Darnassus
        [C_Map.GetAreaInfo(3591)]       = 69,       -- Ruins of Loreth'Aran/Darnassus
        [C_Map.GetAreaInfo(3596)]       = A and playerClass == "SHAMAN" and 1135, -- The Hidden Reef/The Earthen Ring (only for Alliance shamans)
        [C_Map.GetAreaInfo(3598)]       = 69,       -- Wyrmscar Island/Darnassus
        [C_Map.GetAreaInfo(3615)]       = 1135,     -- Throne of the Elements/The Earthen Ring
        [C_Map.GetAreaInfo(3623)]       = 933,      -- Aeris Landing/The Consortium
        [C_Map.GetAreaInfo(3636)]       = 1135,     -- Elemental Plateau/The Earthen Ring
        [C_Map.GetAreaInfo(3673)]       = 47,       -- Nesingwary Safari/Ironforge
        [C_Map.GetAreaInfo(3628)]       = A and 930 or H and 911, -- Halaa/Exodar or Silvermoon City
        [C_Map.GetAreaInfo(3630)]       = 933,      -- Oshu'gun/The Consortium
        [C_Map.GetAreaInfo(3631)]       = 933,      -- Spirit Fields/The Consortium
        [C_Map.GetAreaInfo(3644)]       = 930,      -- Telredor/Exodar
        [C_Map.GetAreaInfo(3645)]       = 530,      -- Zabra'jin/Darkspear Trolls
        [C_Map.GetAreaInfo(3646)]       = 970,      -- Quagg Ridge/Sporeggar
        [C_Map.GetAreaInfo(3647)]       = 970,      -- The Spawning Glen/Sporeggar
        [C_Map.GetAreaInfo(3649)]       = 970,      -- Sporeggar/Sporeggar
        [C_Map.GetAreaInfo(3652)]       = 970,      -- Funggor Cavern/Sporeggar
        [C_Map.GetAreaInfo(3674)]       = 942,      -- Cenarion Thicket/Cenarion Expedition
        [C_Map.GetAreaInfo(3679)]       = 1031,     -- Skettis/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3680)]       = 1031,     -- Blackwind Valley/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3681)]       = 934,      -- Firewing Point/The Scryers
        [C_Map.GetAreaInfo(3683)]       = 941,      -- Stonebreaker Hold/The Mag'har
        [C_Map.GetAreaInfo(3684)]       = 69,       -- Allerian Stronghold/Darnassus
        [C_Map.GetAreaInfo(3690)]       = 1031,     -- Blackwind Lake/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3691)]       = 1031,     -- Lake Ere'Noru/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3718)]       = 530,      -- Swamprat Post/Darkspear Trolls
        [C_Map.GetAreaInfo(3719)]       = 941,      -- Bleeding Hollow Ruins/The Mag'har
        [C_Map.GetAreaInfo(3744)]       = 76,       -- Shadowmoon Village/Orgrimmar
        [C_Map.GetAreaInfo(3745)]       = 1174,     -- Wildhammer Stronghold/Wildhammer Clan
        [C_Map.GetAreaInfo(3754)]       = 932,      -- Altar of Sha'tar/The Aldor
        [C_Map.GetAreaInfo(3758)]       = 1015,     -- Netherwing Fields/Netherwing
        [C_Map.GetAreaInfo(3759)]       = 1015,     -- Netherwing Ledge/Netherwing
        [C_Map.GetAreaInfo(3766)]       = 978,      -- Orebor Harborage/Kurenai
        [C_Map.GetAreaInfo(3778)]       = 1068,     -- Draenethyst Mine/Explorer's League
        [C_Map.GetAreaInfo(3769)]       = 941,      -- Thunderlord Stronghold/The Mag'har
        [C_Map.GetAreaInfo(3771)]       = 69,       -- The Living Grove/Darnassus
        [C_Map.GetAreaInfo(3772)]       = 69,       -- Sylvanaar/Darnassus
        [C_Map.GetAreaInfo(3784)]       = 1031,     -- Forge Camp: Terror/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3785)]       = 1031,     -- Forge Camp: Wrath/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3786)]       = 1038,     -- Ogri'la/Ogri'la
        [C_Map.GetAreaInfo(3792)]       = 933,      -- Mana-Tombs/The Consortium
        [C_Map.GetAreaInfo(3801)]       = 941,      -- Mag'har Grounds/The Mag'har
        [C_Map.GetAreaInfo(3806)]       = 911,      -- Supply Caravan/Silvermoon City
        [C_Map.GetAreaInfo(3808)]       = 942,      -- Cenarion Post/Cenarion Expedition
        [C_Map.GetAreaInfo(3816)]       = 21,       -- Zeppelin Crash/Booty Bay
        [C_Map.GetAreaInfo(3828)]       = 942,      -- Ruuan Weald/Cenarion Expedition
        [C_Map.GetAreaInfo(3832)]       = 1038,     -- Vortex Summit/Ogri'la
        [C_Map.GetAreaInfo(3839)]       = 1011,     -- Abandoned Armory/Lower City
        [C_Map.GetAreaInfo(3842)]       = 935,      -- Tempest Keep (Netherstorm)/The Sha'tar
        [C_Map.GetAreaInfo(3864)]       = 1031,     -- Bash'ir Landing/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3896)]       = 932,      -- Aldor Rise/The Aldor
        [C_Map.GetAreaInfo(3898)]       = 934,      -- Scryer's Tier/The Scryers
        [C_Map.GetAreaInfo(3899)]       = 1011,     -- Lower City/Lower City
        [C_Map.GetAreaInfo(3901)]       = 69,       -- Allerian Post/Darnassus
        [C_Map.GetAreaInfo(3902)]       = 941,      -- Stonebreaker Camp/The Mag'har
        [C_Map.GetAreaInfo(3918)]       = 54,       -- Toshley's Station/Gnomeregan
        [C_Map.GetAreaInfo(3936)]       = 1174,     -- Deathforge Tower/Wildhammer Clan
        [C_Map.GetAreaInfo(3937)]       = 76,       -- Slag Watch/Orgrimmar
        [C_Map.GetAreaInfo(3938)]       = 934,      -- Sanctum of the Stars/The Scryers
        [C_Map.GetAreaInfo(3951)]       = 942,      -- Evergrove/Cenarion Expedition
        [C_Map.GetAreaInfo(3952)]       = 942,      -- Wyrmskull Bridge/Cenarion Expedition
        [C_Map.GetAreaInfo(3958)]       = 1031,     -- Sha'tari Base Camp/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3965)]       = 1015,     -- Netherwing Mines/Netherwing
        [C_Map.GetAreaInfo(3966)]       = 1015,     -- Dragonmaw Base Camp/Netherwing
        [C_Map.GetAreaInfo(3964)]       = 1031,     -- Skyguard Outpost/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3973)]       = 1031,     -- Blackwind Landing/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3974)]       = 1031,     -- Veil Harr'ik/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3975)]       = 1031,     -- Terokk's Rest/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3976)]       = 1031,     -- Veil Ala'rak/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3977)]       = 1031,     -- Upper Veil Shil'ak/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3978)]       = 1031,     -- Lower Veil Shil'ak/Sha'tari Skyguard
        [C_Map.GetAreaInfo(5554)]       = 935,      -- The Mechanar Entrance/The Sha'tar
        [C_Map.GetAreaInfo(5555)]       = 935,      -- The Botanica Entrance/The Sha'tar
        [C_Map.GetAreaInfo(5556)]       = 935,      -- The Arcatraz Entrance/The Sha'tar

        --------- WotLK ---------
        [C_Map.GetAreaInfo(3987)]       = 1073,     -- The Isle of Spears/The Kalu'ak
        [C_Map.GetAreaInfo(3988)]       = 1073,     -- Kamagua/The Kalu'ak
        [C_Map.GetAreaInfo(3990)]       = 1073,     -- Scalawag Point/The Kalu'ak
        [C_Map.GetAreaInfo(3996)]       = 1068,     -- Baelgun's Excavation Site/Explorer's League
        [C_Map.GetAreaInfo(3997)]       = 1068,     -- Explorers' League Outpost/Explorers' League
        [C_Map.GetAreaInfo(3999)]       = 1068,     -- Steel Gate/Explorers' League
        [C_Map.GetAreaInfo(4018)]       = 1064,     -- Camp Winterhoof/The Taunka
        [C_Map.GetAreaInfo(4023)]       = 1090,     -- Amber Ledge/Kirin Tor
        [C_Map.GetAreaInfo(4024)]       = 1090,     -- Coldarra/Kirin Tor
        [C_Map.GetAreaInfo(4033)]       = 942,      -- Winterfin Village/Cenarion Expedition
        [C_Map.GetAreaInfo(4037)]       = 1064,     -- Taunka'le Village/The Taunka
        [C_Map.GetAreaInfo(4040)]       = 1073,     -- Njord's Breath Bay/The Kalu'ak
        [C_Map.GetAreaInfo(4041)]       = 1073,     -- Kaskala/The Kalu'ak
        [C_Map.GetAreaInfo(4097)]       = 942,      -- Winterfin Caverns/Cenarion Expedition
        [C_Map.GetAreaInfo(4099)]       = 942,      -- Winterfin Retreat/Cenarion Expedition
        [C_Map.GetAreaInfo(4113)]       = 1073,     -- Unu'pe/The Kalu'ak
        [C_Map.GetAreaInfo(4120)]       = 1090,     -- The Nexus/Kirin Tor
        [C_Map.GetAreaInfo(4121)]       = 1090,     -- Transitus Shield/Kirin Tor
        [C_Map.GetAreaInfo(4151)]       = 1064,     -- Westwind Refuge Camp/The Taunka
        [C_Map.GetAreaInfo(4152)]       = 1073,     -- Moa'ki Harbor/The Kalu'ak
        [C_Map.GetAreaInfo(4155)]       = 1073,     -- The Half Shell/The Kalu'ak
        [C_Map.GetAreaInfo(4158)]       = 1037,     -- Stars' Rest/Alliance Vanguard
        [C_Map.GetAreaInfo(4165)]       = 1052,     -- Agmar's Hammer/Horde Expedition
        [C_Map.GetAreaInfo(4169)]       = 1037,     -- Fordragon Hold/Alliance Vanguard
        [C_Map.GetAreaInfo(4170)]       = 1052,     -- Kor'kron Vanguard/Horde Expedition
        [C_Map.GetAreaInfo(4171)]       = A and 1037 or H and 1052, -- The Court of Skulls/Alliance Vanguard or Horde Expedition
        [C_Map.GetAreaInfo(4172)]       = A and 1037 or H and 1052, -- Angrathar the Wrathgate/Alliance Vanguard or Horde Expedition
        [C_Map.GetAreaInfo(4177)]       = 1037,     -- Wintergarde Keep/Alliance Vanguard
        [C_Map.GetAreaInfo(4178)]       = 1037,     -- Wintergarde Mine/Alliance Vanguarde
        [C_Map.GetAreaInfo(4186)]       = 1067,     -- Venomspite/The Hand of Vengeance
        [C_Map.GetAreaInfo(4188)]       = 1037,     -- The Carrion Fields/Alliance Vanguard
        [C_Map.GetAreaInfo(4189)]       = 942,      -- D.E.H.T.A Encampment/Cenarion Expedition
        [C_Map.GetAreaInfo(4190)]       = 1037,     -- Thorson's Post/Alliance Vanguard
        [C_Map.GetAreaInfo(4191)]       = 1106,     -- Light's Trust/Argent Crusade
        [C_Map.GetAreaInfo(4211)]       = 1064,     -- Camp Oneqwah/The Taunka
        [C_Map.GetAreaInfo(4224)]       = 1073,     -- The Briny Pinnacle/The Kalu'ak
        [C_Map.GetAreaInfo(4226)]       = 1073,     -- Iskaal/The Kalu'ak
        [C_Map.GetAreaInfo(4227)]       = 530,      -- Dragon's Fall/Darkspear Trolls
        [C_Map.GetAreaInfo(4233)]       = 1106,     -- Dawn's Reach/Argent Crusade
        [C_Map.GetAreaInfo(4234)]       = 1106,     -- Naxxramas/Argent Crusade
        [C_Map.GetAreaInfo(4243)]       = 1037,     -- Wintergarde Crypt/Alliance Vanguard
        [C_Map.GetAreaInfo(4246)]       = 1037,     -- Wintergarde Mausoleum/Alliance Vanguard
        [C_Map.GetAreaInfo(4253)]       = 2159,     -- 7th Legion Front/7th Legion
        [C_Map.GetAreaInfo(4256)]       = A and 1094 or H and 1124, -- Drak'mar Lake/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4261)]       = 68,       -- Ghostblade Point/Undercity
        [C_Map.GetAreaInfo(4281)]       = 1098,     -- Acherus: The Ebon Hold (Eastern Kingdoms)/Knights of the Ebon Blade
        [C_Map.GetAreaInfo(4284)]       = 47,       -- Nesingwary Base Camp/Ironforge
        [C_Map.GetAreaInfo(4286)]       = 1105,     -- The Bones of Nozronn/The Oracles
        [C_Map.GetAreaInfo(4287)]       = 1104,     -- Kartak's Hold/Frenzyheart Tribe
        [C_Map.GetAreaInfo(4288)]       = 1105,     -- Sparktouched Haven/The Oracles
        [C_Map.GetAreaInfo(4291)]       = 1105,     -- Rainspeaker Canopy/The Oracles
        [C_Map.GetAreaInfo(4292)]       = 1104,     -- Frenzyheart Hill/Frenzyheart Tribe
        [C_Map.GetAreaInfo(4297)]       = 1105,     -- Mosswalker Village/The Oracles
        [C_Map.GetAreaInfo(4303)]       = 1104,     -- Hardknuckle Clearing/Frenzyheart Tribe
        [C_Map.GetAreaInfo(4306)]       = 1105,     -- Mistwhisper Village/The Oracles
        [C_Map.GetAreaInfo(4308)]       = 1104,     -- Spearborn Encampment/Frenzyheart Tribe
        [C_Map.GetAreaInfo(4312)]       = 1098,     -- Ebon Watch/Knights of the Ebon Blade
        [C_Map.GetAreaInfo(4369)]       = 47,       -- Dorian's Outpost/Ironforge
        [C_Map.GetAreaInfo(4342)]       = 1098,     -- Acherus: The Ebon Hold (Death Knight start)/Knights of the Ebon Blade
        [C_Map.GetAreaInfo(4392)]       = 1105,     -- The Stormwright's Shelf/The Oracles
        [C_Map.GetAreaInfo(4429)]       = 1085,     -- Grom'arsh Crash-Site/Warsong Offensive
        [C_Map.GetAreaInfo(4418)]       = 21,       -- K3/Booty Bay
        [C_Map.GetAreaInfo(4428)]       = 1126,     -- Frosthold/The Frostborn
        [C_Map.GetAreaInfo(4441)]       = 1064,     -- Camp Tunka'lo/The Taunka
        [C_Map.GetAreaInfo(4442)]       = 1068,     -- Brann's Base-Camp/Explorers' League
        [C_Map.GetAreaInfo(4458)]       = 21,       -- Sparksocket Minefield/Booty Bay
        [C_Map.GetAreaInfo(4459)]       = 21,       -- Ricket's Folly/Booty Bay
        [C_Map.GetAreaInfo(4479)]       = A and 1094 or H and 1124, -- Winter's Breath Lake/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4485)]       = 1126,     -- The Inventor's Library/The Frostborn
        [C_Map.GetAreaInfo(4487)]       = 1085,     -- Frostfloe Deep/Warsong Offensive
        [C_Map.GetAreaInfo(4501)]       = 1106,     -- The Argent Vanguard/Argent Crusade
        [C_Map.GetAreaInfo(4502)]       = 1126,     -- Mimir's Workshop/The Frostborn
        [C_Map.GetAreaInfo(4503)]       = A and 1094 or H and 1124, -- Ironwall Dam/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4504)]       = 1106,     -- Valley of Echoes/Argent Crusade
        [C_Map.GetAreaInfo(4505)]       = 1106,     -- The Breach/Argent Crusade
        [C_Map.GetAreaInfo(4506)]       = 1106,     -- Scourgeholme/Argent Crusade
        [C_Map.GetAreaInfo(4507)]       = A and 1037 or H and 1052, -- The Broken Front/Alliance Vanguard or Horde Expedition
        [C_Map.GetAreaInfo(4511)]       = A and 1037 or H and 1052, -- The Skybreaker/Alliance Vanguard or Horde Expedition
        [C_Map.GetAreaInfo(4512)]       = A and 1037 or H and 1052, -- Orgrim's Hammer/Alliance Vanguard or Horde Expedition
        [C_Map.GetAreaInfo(4516)]       = 1106,     -- Ironwall Rampart/Argent Crusade
        [C_Map.GetAreaInfo(4522)]       = 1156,     -- Icecrown Citadel/The Ashen Verdict
        [C_Map.GetAreaInfo(4536)]       = A and 1068 or H and 1085, -- Frosthowl Cavern/Explorers' League or Warsong Offensive
        [C_Map.GetAreaInfo(4541)]       = 1106,     -- Vanguard Infirmary/Argent Crusade
        [C_Map.GetAreaInfo(4558)]       = A and 1094 or H and 1124, -- Sunreaver's Command/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4559)]       = A and 1094 or H and 1124, -- Windrunner's Overlook/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4580)]       = 1106,     -- Crusaders' Pinnacle/Argent Crusade
        [C_Map.GetAreaInfo(4593)]       = 1106,     -- The Pit of Fiends/Argent Crusade
        [C_Map.GetAreaInfo(4616)]       = A and 1094 or H and 1124, -- Sunreaver's Sanctuary/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4646)]       = A and 1094 or H and 1124, -- Ashwood Lake/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4658)]       = 1106,     -- Argent Tournament Grounds/Argent Crusade
        [C_Map.GetAreaInfo(4666)]       = A and 1094 or H and 1124, -- Sunreaver Pavilion/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4667)]       = A and 1094 or H and 1124, -- Silver Covenant Pavilion/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4669)]       = 1106,     -- The Ring of Champions/Argent Crusade
        [C_Map.GetAreaInfo(4670)]       = 1106,     -- The Aspirants' Ring/Argent Crusade
        [C_Map.GetAreaInfo(4671)]       = 1106,     -- The Argent Valiants' Ring/Argent Crusade
        [C_Map.GetAreaInfo(4672)]       = A and 1094 or H and 1124, -- The Alliance Valiants' Ring/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4673)]       = A and 1094 or H and 1124, -- The Horde Valiants' Ring/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4674)]       = 1106,     -- Argent Pavilion/Argent Crusade
        [C_Map.GetAreaInfo(4676)]       = A and 1094 or H and 1124, -- Sunreaver Pavilion (Outside)/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4677)]       = A and 1094 or H and 1124, -- Silver Covenant Pavilion (Outside)/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4740)]       = A and 1094 or H and 1124, -- The Silver Enclave/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4760)]       = A and 1094 or H and 1124, -- The Sea Reaver's Run/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(5561)]       = 1090,     -- The Nexus Entrance/Kirin Tor

        --------- Cataclysm ---------
        [C_Map.GetAreaInfo(3707)]       = 72,       -- Alliance Base/Stormwind
        [C_Map.GetAreaInfo(3708)]       = 76,       -- Horde Encampment/Orgrimmar
        [C_Map.GetAreaInfo(3709)]       = 69,       -- Night Elf Village/Darnassus
        [C_Map.GetAreaInfo(4779)]       = 76,       -- Horde Base Camp/Orgrimmar
        [C_Map.GetAreaInfo(4846)]       = 81,       -- Camp Una'fe/Thunder Bluff
        [C_Map.GetAreaInfo(4851)]       = 81,       -- Ruins of Taurajo/Thunder Bluff
        [C_Map.GetAreaInfo(4856)]       = A and 47 or H and 81, -- Bael Modan/Ironforge or Thunder Bluff
        [C_Map.GetAreaInfo(4857)]       = 1135,     -- Firestone Point/The Earthen Ring
        [C_Map.GetAreaInfo(4860)]       = 81,       -- Overgrown Camp/Thunder Bluff
        [C_Map.GetAreaInfo(4872)]       = A and 47 or H and 81, -- Bael'dun Keep/Ironforge or Thunder Bluff
        [C_Map.GetAreaInfo(4912)]       = 76,       -- Warchief's Lookout/Orgrimmar
        [C_Map.GetAreaInfo(4946)]       = A and 47 or H and 81, -- Bael Modan Excavation/Ironforge or Thunder Bluff
        [C_Map.GetAreaInfo(4947)]       = 47,       -- Twinbraid's Patrol/Ironforge
        [C_Map.GetAreaInfo(4948)]       = A and 47 or H and 1133, -- Frazzlecraz Motherlode/Ironforge or Bilgewater Cartel
        [C_Map.GetAreaInfo(4949)]       = 81,       -- Spearhead/Thunder Bluff
        [C_Map.GetAreaInfo(4969)]       = 72,       -- Tranquil Wash/Stormwind
        [C_Map.GetAreaInfo(4970)]       = 76,       -- Legion's Rest/Orgrimmar
        [C_Map.GetAreaInfo(4975)]       = 76,       -- Tenebrous Cavern/Orgrimmar
        [C_Map.GetAreaInfo(4976)]       = 72,       -- Darkbreak Cove/Stormwind
        [C_Map.GetAreaInfo(4986)]       = 81,       -- Vendetta Point/Thunder Bluff
        [C_Map.GetAreaInfo(5050)]       = 1204,     -- Firelands Hatchery (The Hatchery)/Avengers of Hyjal
        [C_Map.GetAreaInfo(5064)]       = 1204,     -- Firelands Forgeworks (The Anvil of Flame)/Avengers of Hyjal
        [C_Map.GetAreaInfo(5067)]       = 1204,     -- The Inner Spire/Avengers of Hyjal
        [C_Map.GetAreaInfo(5099)]       = 1204,     -- The Crucible of Flame (The Crucible)/Avengers of Hyjal
        [C_Map.GetAreaInfo(5137)]       = 1133,     -- The Krazzworks/Bilgewater Cartel
        [C_Map.GetAreaInfo(5140)]       = A and 72 or H and 1133, -- Highbank/Stormwind or Bilgewater Cartel
        [C_Map.GetAreaInfo(5155)]       = 1091,     -- Vermillion Redoubt/The Wyrmrest Accord
        [C_Map.GetAreaInfo(5248)]       = 72,       -- Voldrin's Hold/Stormwind
        [C_Map.GetAreaInfo(5249)]       = 76,       -- Stygian Bounty/Orgrimmar
        [C_Map.GetAreaInfo(5293)]       = 1171,     -- Crumbling Depths/Therazane
        [C_Map.GetAreaInfo(5294)]       = 1171,     -- Shuddering Spires/Therazane
        [C_Map.GetAreaInfo(5295)]       = 1171,     -- The Pale Roost/Therazane
        [C_Map.GetAreaInfo(5296)]       = 1171,     -- Therazane's Throne/Therazane
        [C_Map.GetAreaInfo(5297)]       = 1171,     -- Halcyon Egress/Therazane
        [C_Map.GetAreaInfo(5298)]       = 1171,     -- Twilight Precipice/Therazane
        [C_Map.GetAreaInfo(5299)]       = 1171,     -- Lorthuna's Gate/Therazane
        [C_Map.GetAreaInfo(5300)]       = 1171,     -- Verlok Stand/Therazane
        [C_Map.GetAreaInfo(5302)]       = 1171,     -- Crimson Expanse/Therazane
        [C_Map.GetAreaInfo(5338)]       = 1171,     -- Fungal Deep/Therazane
        [C_Map.GetAreaInfo(5408)]       = 1068,     -- Explorer's League Digsite/Explorer's League
        [C_Map.GetAreaInfo(5437)]       = 1135,     -- Ring of the Elements/The Earthen Ring
        [C_Map.GetAreaInfo(5438)]       = 1135,     -- The Maw of Madness/The Earthen Ring
        [C_Map.GetAreaInfo(5439)]       = 1135,     -- Ruins of Drakgor/The Earthen Ring
        [C_Map.GetAreaInfo(5461)]       = A and 72 or H and 1133, -- Dragonmaw Pass/Stormwind or Bilgewater Cartel
        [C_Map.GetAreaInfo(5462)]       = A and 72 or H and 1133, -- Wyrms' Bend/Stormwind or Bilgewater Cartel
        [C_Map.GetAreaInfo(5470)]       = A and 72 or H and 1133, -- Victor's Point/Stormwind or Bilgewater Cartel
        [C_Map.GetAreaInfo(5595)]       = 1091,     -- Obsidian Forest/The Wyrmrest Accord
        [C_Map.GetAreaInfo(5660)]       = 1091,     -- Obsidian Lair/The Wyrmrest Accord
        [C_Map.GetAreaInfo(5664)]       = 1135,     -- Iso'rath/The Earthen Ring

        --------- MoP ---------
        [C_Map.GetAreaInfo(4081)]       = 81,       -- The Dawnchaser/Thunder Bluff
        [C_Map.GetAreaInfo(5876)]       = 1271,     -- Serpent's Heart/Order of the Cloud Serpent
        [C_Map.GetAreaInfo(5931)]       = 1271,     -- The Arboretum/Order of the Cloud Serpent
        [C_Map.GetAreaInfo(5974)]       = 1341,     -- Jade Temple Grounds/The August Celestials
        [C_Map.GetAreaInfo(5975)]       = 1341,     -- Temple of the Jade Serpent/The August Celestials
        [C_Map.GetAreaInfo(5976)]       = 1270,     -- Gate of the Setting Sun/Shado-Pan
        [C_Map.GetAreaInfo(6012)]       = 1271,     -- Windward Isle/Order of the Cloud Serpent
        [C_Map.GetAreaInfo(6013)]       = A and 1376 or H and 1375, -- The Dawnchaser (Retreat)/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6016)]       = 69,       -- Sentinel Basecamp/Darnassus
        [C_Map.GetAreaInfo(6022)]       = 1271,     -- Mistveil Sea/Order of the Cloud Serpent
        [C_Map.GetAreaInfo(6025)]       = 47,       -- Nesingwary's Safari/Ironforge
        [C_Map.GetAreaInfo(6048)]       = 1341,     -- Temple of the Red Crane/The August Celestials
        [C_Map.GetAreaInfo(6059)]       = A and 1353 or H and 1352, -- Binan Village/Tushui Pandaren or Huojin Pandaren
        [C_Map.GetAreaInfo(6080)]       = 1271,     -- Serpent's Overlook/Order of the Cloud Serpent
        [C_Map.GetAreaInfo(6117)]       = 1341,     -- Fountain of the Everseeing/The August Celestials
        [C_Map.GetAreaInfo(6118)]       = 1341,     -- The Scrollkeeper's Sanctum/The August Celestials
        [C_Map.GetAreaInfo(6119)]       = 1341,     -- Terrace of the Twin Dragons/The August Celestials
        [C_Map.GetAreaInfo(6120)]       = 1341,     -- The Heart of Jade/The August Celestials
        [C_Map.GetAreaInfo(6143)]       = 1341,     -- Mogu'shan Palace1/The August Celestials
        [C_Map.GetAreaInfo(6155)]       = 1341,     -- Cradle of Chi-Ji/The August Celestials
        [C_Map.GetAreaInfo(6160)]       = 1341,     -- Angkhal Pavilion/The August Celestials
        [C_Map.GetAreaInfo(6161)]       = 1341,     -- Pedestal of Hope/The August Celestials
        [C_Map.GetAreaInfo(6162)]       = 1341,     -- Dome Balrissa/The August Celestials
        [C_Map.GetAreaInfo(6174)]       = 1341,     -- Temple of the White Tiger/The August Celestials
        [C_Map.GetAreaInfo(6182)]       = 1341,     -- Mogu'shan Palace2/The August Celestials
        [C_Map.GetAreaInfo(6213)]       = 1341,     -- Niuzao Temple/The August Celestials
        [C_Map.GetAreaInfo(6295)]       = 1345,     -- Seat of Knowledge/The Lorewalkers
        [C_Map.GetAreaInfo(6368)]       = 1302,     -- Soggy's Gamble/The Anglers
        [C_Map.GetAreaInfo(6371)]       = A and 1376 or H and 1375, -- The Southern Isles/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6393)]       = 1270,     -- Serpent's Spine (Valley of the Four Winds)/Shado-Pan
        [C_Map.GetAreaInfo(6394)]       = 1270,     -- Serpent's Spine (Vale of Eternal Blossoms)/Shado-Pan
        [C_Map.GetAreaInfo(6395)]       = 1270,     -- Serpent's Spine (Kun-Lai Summit)/Shado-Pan
        [C_Map.GetAreaInfo(6401)]       = 1302,     -- Shelf of Mazu/The Anglers
        [C_Map.GetAreaInfo(6402)]       = 1302,     -- Wreck of the Mist-Hopper/The Anglers
        [C_Map.GetAreaInfo(6433)]       = 1302,     -- Lonesome Cove/The Anglers
        [C_Map.GetAreaInfo(6482)]       = A and 1341, -- The Summer Terrace/The August Celestials
        [C_Map.GetAreaInfo(6498)]       = 1341,     -- Gate of the August Celestials/The August Celestials
        [C_Map.GetAreaInfo(6512)]       = 1271,     -- The Widow's Wail/Order of the Cloud Serpent
        [C_Map.GetAreaInfo(6513)]       = 1271,     -- Oona Kagu/Order of the Cloud Serpent
        [C_Map.GetAreaInfo(6533)]       = 72,       -- The Skyfire (Jade Forest)/Stormwind
        [C_Map.GetAreaInfo(6560)]       = H and 1341, -- The Golden Terrace/The August Celestials
        [C_Map.GetAreaInfo(6566)]       = A and 1376 or H and 1375, -- Domination Point/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6595)]       = A and 1376 or H and 1375, -- The Skyfire/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6596)]       = A and 1376 or H and 1375, -- Lion's Landing1/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6597)]       = A and 1376 or H and 1375, -- Sparkrocket Outpost/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6600)]       = A and 1376 or H and 1375, -- Blacksand Spillway/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6601)]       = A and 1376 or H and 1375, -- Bilgewater Beach/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6602)]       = A and 1376 or H and 1375, -- The Boiling Crustacean/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6604)]       = A and 1376 or H and 1375, -- Quickchop's Lumber Farm/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6609)]       = A and 1376 or H and 1375, -- Ruins of Ogudei/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6643)]       = A and 1376 or H and 1375, -- Lion's Landing/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6644)]       = A and 1376 or H and 1375, -- Domination Point (Horde)/Operation: Shieldwall or Dominance Offensive
        [C_Map.GetAreaInfo(6701)]       = 54,       -- Beeble's Wreck/Gnomeregan
        [C_Map.GetAreaInfo(6702)]       = 1133,     -- Bozzle's Wreck/Bilgewater Cartel
        [C_Map.GetAreaInfo(6762)]       = 1710,     -- Shattrath City Center/Sha'tari Defense
        [C_Map.GetAreaInfo(6771)]       = 1341,     -- Celestial Tournament/The August Celestials

        ---------- WoD ----------
        [C_Map.GetAreaInfo(6926)]       = 1515,     -- Veil Shadar/Arakkoa Outcasts
        [C_Map.GetAreaInfo(6933)]       = 1515,     -- Terokkar Refuge/Arakkoa Outcasts
        [C_Map.GetAreaInfo(6999)]       = 946,      -- Admiral Taylor's Garrison/Honor Hold
        [C_Map.GetAreaInfo(7032)]       = 1710,     -- Garden of K'ure/Sha'tari Defense
        [C_Map.GetAreaInfo(7060)]       = 47,       -- Hemet's Happy Hunting Grounds/Ironforge
        [C_Map.GetAreaInfo(7061)]       = 930,      -- Yrel's Watch/Exodar
        [C_Map.GetAreaInfo(7063)]       = 81,       -- Riverside Post/Thunder Bluff
        [C_Map.GetAreaInfo(7072)]       = 889,      -- Ancestral Grounds/Warsong Outriders
        [C_Map.GetAreaInfo(7074)]       = 930,      -- Telaar/Exodar
        [C_Map.GetAreaInfo(7081)]       = 930,      -- Telaari Station/Exodar
        [C_Map.GetAreaInfo(7139)]       = 1135,     -- Elemental Plateau/The Earthen Ring
        [C_Map.GetAreaInfo(7141)]       = 1710,     -- Arch of Sha'tar/Sha'tari Defense
        [C_Map.GetAreaInfo(7156)]       = 889,      -- Anguish Point/Warsong Outriders
        [C_Map.GetAreaInfo(7162)]       = 1711,     -- Pinchwhistle Gearworks/Steamwheedle Preservation Society
        [C_Map.GetAreaInfo(7163)]       = 1711,     -- Pinchwhistle Point/Steamwheedle Preservation Society
        [C_Map.GetAreaInfo(7164)]       = 1711,     -- Wreck of the Mother Lode/Steamwheedle Preservation Society
        [C_Map.GetAreaInfo(7197)]       = 76,       -- Axefall/Orgrimmar
        [C_Map.GetAreaInfo(7198)]       = 72,       -- Southport/Stormwind
        [C_Map.GetAreaInfo(7208)]       = 946,      -- The Briny Barnacle/Honor Hold
        [C_Map.GetAreaInfo(7222)]       = 946,      -- Admiral Taylor's Farm/Honor Hold
        [C_Map.GetAreaInfo(7266)]       = 1711,     -- The Rusty Cylinder/Steamwheedle Preservation Society
        [C_Map.GetAreaInfo(7269)]       = 1710,     -- Spire of Light/Sha'tari Defense
        [C_Map.GetAreaInfo(7295)]       = 930,      -- Telaari Tankworks/Exodar
        [C_Map.GetAreaInfo(7377)]       = 2135,     -- Time-Lost Glade/Chromie
        [C_Map.GetAreaInfo(7389)]       = 1710,     -- Bladefury's Command/Sha'tari Defense
        [C_Map.GetAreaInfo(7391)]       = 1710,     -- The Path of Glory/Sha'tari Defense
        [C_Map.GetAreaInfo(7392)]       = 1731,     -- Pillars of Fate/Council of Exarchs
        [C_Map.GetAreaInfo(7417)]       = 1710,     -- Sha'tari Anchorage/Sha'tari Defense
        [C_Map.GetAreaInfo(7418)]       = 1710,     -- Shattrath Port Authority/Sha'tari Defense
        [C_Map.GetAreaInfo(7419)]       = 1710,     -- Beacon of Sha'tar/Sha'tari Defense
        [C_Map.GetAreaInfo(7420)]       = 1710,     -- Shattrath City/Sha'tari Defense
        [C_Map.GetAreaInfo(7421)]       = 1710,     -- Shattrath Commons/Sha'tari Defense
        [C_Map.GetAreaInfo(7422)]       = 1710,     -- Sha'tari Market District/Sha'tari Defense
        [C_Map.GetAreaInfo(7433)]       = 930,      -- Telaari Worksite/Exodar
        [C_Map.GetAreaInfo(7453)]       = 1710,     -- Sha'tar Way Station/Sha'tari Defense
        [C_Map.GetAreaInfo(7454)]       = 1710,     -- Sha'tari Skymesa/Sha'tari Defense
        [C_Map.GetAreaInfo(7455)]       = 1710,     -- Shattrath Residential District/Sha'tari Defense
        [C_Map.GetAreaInfo(7480)]       = 1710,     -- Shattrath Overlook/Sha'tari Defense
        [C_Map.GetAreaInfo(7484)]       = 72,       -- Southport Worksite/Stormwind
        [C_Map.GetAreaInfo(7536)]       = 1515,     -- Aktar's Post/Arakkoa Outcasts
        [C_Map.GetAreaInfo(7641)]       = 1850,     -- Fang'rila/The Saberstalkers
        [C_Map.GetAreaInfo(7655)]       = A and 1710 or H and 1708, -- Rangari Refuge/Sha'tari Defense or Laughing Skull Orcs
        [C_Map.GetAreaInfo(7739)]       = 1850,     -- Blackfang Challenge Arena/The Saberstalkers

        --------- Legion ---------
        [C_Map.GetAreaInfo(7342)]       = 68,       -- Queen's Reprisal/Undercity
        [C_Map.GetAreaInfo(7542)]       = A and 1134 or H and 68, -- Weeping Bluffs/Gilneas or Undercity
        [C_Map.GetAreaInfo(7555)]       = A and 1134 or H and 68, -- Skyfire Triage Camp/Gilneas or Undercity
        [C_Map.GetAreaInfo(7563)]       = A and 1134 or H and 68, -- Cove of Nashal/Gilneas or Undercity
        [C_Map.GetAreaInfo(7564)]       = A and 1134 or H and 68, -- Forsaken Foothold/Gilneas or Undercity
        [C_Map.GetAreaInfo(7638)]       = 1106,     -- Sanctum of Light (Paladin Class Hall)/Argent Crusade
        [C_Map.GetAreaInfo(7642)]       = 1134,     -- Bradensbrook/Gilneas
        [C_Map.GetAreaInfo(7650)]       = 1134,     -- Marl's Stead/Gilneas
        [C_Map.GetAreaInfo(7679)]       = 1098,     -- Acherus: The Ebon Hold (Broken Isles)/Knights of the Ebon Blade
        [C_Map.GetAreaInfo(7698)]       = A and 1134 or H and 68, -- Dreadwake's Landing/Gilneas or Undercity
        [C_Map.GetAreaInfo(7699)]       = A and 1134 or H and 68, -- Greywatch/Gilneas or Undercity
        [C_Map.GetAreaInfo(7700)]       = A and 1134 or H and 68, -- Ranger's Foothold/Gilneas or Undercity
        [C_Map.GetAreaInfo(7701)]       = 1134,     -- Crowley's Overlook/Gilneas
        [C_Map.GetAreaInfo(7733)]       = 47,       -- Nesingwary's Retreat/Ironforge
        [C_Map.GetAreaInfo(7743)]       = 1098,     -- Acherus: The Ebon Hold (Icecrown)/Knights of the Ebon Blade
        [C_Map.GetAreaInfo(7773)]       = A and 1134 or H and 68, -- Greymane's Offensive/Gilneas or Undercity
        [C_Map.GetAreaInfo(7778)]       = 1134,     -- Heathrow Manor/Gilneas
        [C_Map.GetAreaInfo(7779)]       = 1134,     -- Radcliffe Landing/Gilneas
        [C_Map.GetAreaInfo(7787)]       = 1894,     -- Vault of the Wardens/The Wardens
        [C_Map.GetAreaInfo(7789)]       = A and 1134 or H and 68, -- Bronzeleaf Thicket/Gilneas or Undercity
        [C_Map.GetAreaInfo(7813)]       = 1948,     -- Skyhold (Warrior)/Valarjar
        [C_Map.GetAreaInfo(7814)]       = 1894,     -- Vault of the Wardens (Demon Hunter)/The Wardens
        [C_Map.GetAreaInfo(7836)]       = 1828,     -- Mucksnout Den/Highmountain Tribe
        [C_Map.GetAreaInfo(7849)]       = A and 1134 or H and 68, -- Cullen's Post/Gilneas or Undercity
        [C_Map.GetAreaInfo(7850)]       = A and 1134 or H and 68, -- Lorna's Watch/Gilneas or Undercity
        [C_Map.GetAreaInfo(7879)]       = 1090,     -- Hall of the Guardian (Mage Class Hall)/Kirin Tor
        [C_Map.GetAreaInfo(7903)]       = 1341,     -- Temple of Five Dawns (Monk)/The August Celestials
        [C_Map.GetAreaInfo(7904)]       = 1341,     -- Shrine of Five Dawns (Monk)/The August Celestials
        [C_Map.GetAreaInfo(8051)]       = A and 1134 or H and 68, -- Cordana's Apex/Gilneas or Undercity
        [C_Map.GetAreaInfo(8078)]       = A and 1134 or H and 68, -- Nightwatcher's Perch/Gilneas or Undercity
        [C_Map.GetAreaInfo(8147)]       = 1894,     -- Isle of the Watchers/The Wardens
        [C_Map.GetAreaInfo(8237)]       = UnitClassBase("player") == "SHAMAN" and 1135, -- Alluvanon's Delta/The Earthen Ring
        [C_Map.GetAreaInfo(8270)]       = 1975,     -- Margoss's Retreat/Conjurer Margoss
        [C_Map.GetAreaInfo(8273)]       = 1134,     -- Thorton's Cottage/Gilneas
        [C_Map.GetAreaInfo(8284)]       = A and 69 or H and 911, -- Illidari Redoubt/Darnassus or Silvermoon City
        [C_Map.GetAreaInfo(8300)]       = A and 1134 or H and 68, -- Theodric's Lodge/Gilneas or Undercity
        [C_Map.GetAreaInfo(8301)]       = A and 1134 or H and 68, -- Greywatch Barracks/Gilneas or Undercity
        [C_Map.GetAreaInfo(8302)]       = A and 1134 or H and 68, -- The Oblivion/Gilneas or Undercity
        [C_Map.GetAreaInfo(8304)]       = A and 1134 or H and 68, -- Starstalker's Point/Gilneas or Undercity
        [C_Map.GetAreaInfo(8320)]       = A and 1134 or H and 68, -- Darkfollow's Spire/Gilneas or Undercity
        [C_Map.GetAreaInfo(8324)]       = A and 1134 or H and 68, -- Whisperwind's Citadel
        [C_Map.GetAreaInfo(8328)]       = A and 1134 or H and 68, -- Blackhawk's Bulwark/Gilneas or Undercity
        [C_Map.GetAreaInfo(8370)]       = 1894,     -- Watchers' Aerie/The Wardens
        [C_Map.GetAreaInfo(8371)]       = 1894,     -- Wardens' Redoubt/The Wardens
        [C_Map.GetAreaInfo(8394)]       = 1134,     -- Carlisle Cottage/Gilneas

        --------- BfA ---------
        [C_Map.GetAreaInfo(8925)]       = 47,       -- Nesingwary's Trek/Ironforge
        [C_Map.GetAreaInfo(9007)]       = 1068,     -- Explorer's League Campsite/Explorer's League
        [C_Map.GetAreaInfo(9310)]       = 2386,     -- The Wound/Champions of Azeroth
        [C_Map.GetAreaInfo(9329)]       = 2387,     -- Seeker's Outpost/Tortollan Seekers
        [C_Map.GetAreaInfo(9470)]       = 2395,     -- Mildenhall Brewery/Honeyback Hive
        [C_Map.GetAreaInfo(9473)]       = 69,       -- Staghelm Point/Darnassus
        [C_Map.GetAreaInfo(9474)]       = 1133,     -- Southwind Village/Bilgewater Cartel
        [C_Map.GetAreaInfo(9494)]       = 1133,     -- Warfront: The Battle for Stromgarde (Ar'gorok)/Bilgewater Cartel
        [C_Map.GetAreaInfo(9556)]       = 2387,     -- Tortaka Refuge/Tortollan Seekers
        [C_Map.GetAreaInfo(9667)]       = 2386,     -- Chamber of Heart (Destroyed)/Champions of Azeroth
        [C_Map.GetAreaInfo(9693)]       = 2387,     -- Seeker's Vista/Tortollan Seekers
        [C_Map.GetAreaInfo(9714)]       = 2387,     -- Seeker's Expedition/Tortollan Seekers
        [C_Map.GetAreaInfo(9735)]       = 1133,     -- Ar'gorok/Bilgewater Cartel
        [C_Map.GetAreaInfo(9747)]       = 72,       -- Warfront: The Battle for Stromgarde (Refuge Pointe)/Stormwind
        [C_Map.GetAreaInfo(9750)]       = 68,       -- Hammerfall/Undercity
        [C_Map.GetAreaInfo(9755)]       = 47,       -- Thandol Span/Ironforge
        [C_Map.GetAreaInfo(9756)]       = 68,       -- Thoradin's Wall (Horde Warfront)/Undercity
        [C_Map.GetAreaInfo(9758)]       = 47,       -- Thoradin's Wall (Alliance Warfront)/Ironforge
        [C_Map.GetAreaInfo(9759)]       = A and 47 or H and 68, -- Thoradin's Wall/Ironforge or Undercity
        [C_Map.GetAreaInfo(10006)]      = 2387,     -- House of Jol/Tortollan Seekers
        [C_Map.GetAreaInfo(10504)]      = 2386,     -- Chamber of Heart (rebuilt)/Champions of Azeroth
        [C_Map.GetAreaInfo(12905)]      = 2386,     -- Chamber of Heart (scenario)/Champions of Azeroth
        [C_Map.GetAreaInfo(13539)]      = 1098,     -- Acherus: The Ebon Hold (Class Hall)/Knights of the Ebon Blade

        --------- Shadowlands ---------
        [C_Map.GetAreaInfo(10565)]      = self.covenantRepID, -- Oribos/Covenant
        [C_Map.GetAreaInfo(10979)]      = 2413,     -- Darkhaven/Court of Harvesters
        [C_Map.GetAreaInfo(10995)]      = 2439,     -- Halls of Atonement/The Avowed
        [C_Map.GetAreaInfo(11533)]      = self.covenantRepID == 3 and 2422 or 2465, -- Tirna Noch/Night Fae or The Wild Hunt
        [C_Map.GetAreaInfo(12796)]      = 2462,     -- The Stitchyard/Stitchmasters
        [C_Map.GetAreaInfo(12876)]      = 2410,     -- Seat of the Primus/The Undying Army
        [C_Map.GetAreaInfo(12901)]      = 2462,     -- Etheric Vault/Stitchmasters
        [C_Map.GetAreaInfo(13209)]      = self.covenantRepID, -- Oribos: Netherhollow/Covenant
        [C_Map.GetAreaInfo(13346)]      = 2462,     -- Body Banks/Stitchmasters
        [C_Map.GetAreaInfo(13347)]      = 2462,     -- Thread House/Stitchmasters
        [C_Map.GetAreaInfo(13348)]      = 2462,     -- Amputory/Stitchmasters
        [C_Map.GetAreaInfo(13367)]      = self.covenantRepID == 3 and 2422 or 2465, -- Queen's Conservatory/Night Fae or The Wild Hunt
        [C_Map.GetAreaInfo(13414)]      = 2413,     -- The Sinposium/Court of Harvesters
        [C_Map.GetAreaInfo(13498)]      = self.covenantRepID, -- Oribos: Ring of Transference/Covenant
        [C_Map.GetAreaInfo(13499)]      = self.covenantRepID, -- Oribos: Ring of Fates/Covenant
        [C_Map.GetAreaInfo(13515)]      = 2407,     -- Seat of the Archon: Font of Fealty/The Ascended
        [C_Map.GetAreaInfo(13555)]      = 2462,     -- Sixfold Recluse/Stitchmasters
        [C_Map.GetAreaInfo(13625)]      = 2472,     -- Keeper's Respite/The Archivists' Codex
        [C_Map.GetAreaInfo(13652)]      = 2472,     -- Reliquarty of Rememberance/The Archivists' Codex
        [C_Map.GetAreaInfo(13691)]      = 2472,     -- Chamber of Knowledge/The Archivists' Codex
        [C_Map.GetAreaInfo(13692)]      = 2472,     -- Chamber of Wisdom/The Archivists' Codex

        --------- Dragonflight ---------
        [C_Map.GetAreaInfo(13587)]      = 2526,     -- Winterpelt Hollow/Winterpelt Furbolg
        [C_Map.GetAreaInfo(13710)]      = 2511,     -- Uktulut Backwater/Iskaara Tuskarr
        [C_Map.GetAreaInfo(13717)]      = self.dragonflightRepID, -- Obsidian Citadel/Wrathion or Sabellian
        [C_Map.GetAreaInfo(13720)]      = self.dragonflightRepID, -- Dragonbane Keep/Wrathion of Sabellian
        [C_Map.GetAreaInfo(13725)]      = 2507,     -- Life Vault Ruins/Dragonscale Expedition
        [C_Map.GetAreaInfo(13729)]      = 2507,     -- Crumbling Life Archway/Dragonscale Expedition
        [C_Map.GetAreaInfo(13732)]      = 2507,     -- Dragonscale Basecamp/Dragonscale Expedition
        [C_Map.GetAreaInfo(13733)]      = 2507,     -- Wild Preserve/Dragonscale Expedition
        [C_Map.GetAreaInfo(13739)]      = self.dragonflightRepID, -- Obsidian Bulwark/Wrathion or Sabellian
        [C_Map.GetAreaInfo(13766)]      = 2517,     -- Nelthazan Ruins/Dragonscale Expedition
        [C_Map.GetAreaInfo(13767)]      = 2507,     -- Emberwatch/Dragonscale Expedition
        [C_Map.GetAreaInfo(13782)]      = 2520,     -- Nokhudon Hold/Clan Nokhud
        [C_Map.GetAreaInfo(13801)]      = 2510,     -- Tyrhold/Valdrakken Accord
        [C_Map.GetAreaInfo(13802)]      = 2510,     -- Tyrhold Reservoir/Valdrakken Accord
        [C_Map.GetAreaInfo(13817)]      = 989,      -- Shifting Sands/Keepers of Time
        [C_Map.GetAreaInfo(13818)]      = 989,      -- Temporal Conflux/Keepers of Time
        [C_Map.GetAreaInfo(13822)]      = 989,      -- The Flowing Forest/Keeers of Time
        [C_Map.GetAreaInfo(13825)]      = 1090,     -- Azure Archives/Kirin Tor
        [C_Map.GetAreaInfo(13833)]      = 2507,     -- Shiverweb Vale/Dragonscale Expedition
        [C_Map.GetAreaInfo(13834)]      = 1090,     -- Camp Antonidas/Kirin Tor
        [C_Map.GetAreaInfo(13835)]      = 2550,     -- Cobalt Assembly/Cobalt Assembly
        [C_Map.GetAreaInfo(13837)]      = 2511,     -- Iskaara/Iskaara Tuskarr
        [C_Map.GetAreaInfo(13851)]      = 2550,     -- Cobalt Library/Cobalt Assembly
        [C_Map.GetAreaInfo(13859)]      = 2507,     -- Camp Nowhere/Dragonscale Expedition
        [C_Map.GetAreaInfo(13861)]      = 2507,     -- Bluefeather Cliffs/Dragonscale Expedition
        [C_Map.GetAreaInfo(13862)]      = 2510,     -- Valdrakken/Valdrakken Accord
        [C_Map.GetAreaInfo(13886)]      = 2507,     -- Whaler's Nook/Dragonscale Expedition
        [C_Map.GetAreaInfo(13888)]      = 2507,     -- Three-Falls Lookout/Dragonscale Expedition
        [C_Map.GetAreaInfo(13895)]      = 2507,     -- Theron's Watch/Dragonscale Expedition
        [C_Map.GetAreaInfo(13934)]      = 1090,     -- Rhonin's Shield/Kirin Tor
        [C_Map.GetAreaInfo(13939)]      = 2507,     -- Wingrest Embassy/Dragonscale Expedition
        [C_Map.GetAreaInfo(13941)]      = self.dragonflightRepID, -- Obsidian Throne/Wrathion or Sabellian
        [C_Map.GetAreaInfo(14017)]      = 2510,     -- Vakthros Summit/Valdrakken Accord
        [C_Map.GetAreaInfo(14020)]      = 2510,     -- Lundedane/Valdrakken Accord
        [C_Map.GetAreaInfo(14079)]      = 2510,     -- Lilac Ramble/Valdrakken Accord
        [C_Map.GetAreaInfo(14089)]      = 2510,     -- Vakthros/Valdrakken Accord
        [C_Map.GetAreaInfo(14096)]      = 2510,     -- Valdrakken: Little Scles Daycare
        [C_Map.GetAreaInfo(14155)]      = 2511,     -- Morqut Islet/Iskaara Tuskarr
        [C_Map.GetAreaInfo(14429)]      = 2511,     -- The Filled Bowl/Iskaara Tuskarr
        [C_Map.GetAreaInfo(14430)]      = 1090,     -- Camp Antonidas: Mage's Rest/Kirin Tor
        [C_Map.GetAreaInfo(14432)]      = 2507,     -- The Missing Hinge Inn/Dragonscale Expedition
        [C_Map.GetAreaInfo(14437)]      = 2550,     -- Training Grounds/Cobalt Assembly
        [C_Map.GetAreaInfo(14438)]      = 2544,     -- Khadin's Cave/Artisan's Consortium
        [C_Map.GetAreaInfo(14489)]      = 2510,     -- Valdrakken: The Seat of the Aspects/Valdrakken Accord
        [C_Map.GetAreaInfo(14490)]      = 2510,     -- Valdrakken: The Victorious Visage/Valdrakken Accord
        [C_Map.GetAreaInfo(14493)]      = 2510,     -- Valdrakken: Azure Archives Annex/Valdrakken Accord
        [C_Map.GetAreaInfo(14497)]      = 2510,     -- Valdrakken: Cascade's Edge/Valdrakken Accord
        [C_Map.GetAreaInfo(14499)]      = 2510,     -- Valdrakken: Gladiator's Refuge/Valdrakken Accord
        [C_Map.GetAreaInfo(14504)]      = 2510,     -- Valdrakken: The Sapphire Enclave/Valdrakken Accord
        [C_Map.GetAreaInfo(14506)]      = 2510,     -- Valdrakken: The Obsidian Enclave/Valdrakken Accord
        [C_Map.GetAreaInfo(14509)]      = 2544,     -- Valdrakken: The Artisan's Market/Artisan's Consortium
        [C_Map.GetAreaInfo(14530)]      = 2510,     -- Valdrakken Treasury Hoard/Valdrakken Accord
    }
    return subZonesAndFactions
end